// Persistence of Vision Ray Tracer Scene Description File
// File: *.pov
// Vers: 3.1
// Auth: Porrey

global_settings { assumed_gamma 2.2 }
#default { pigment { color rgb 1 } finish { ambient .4 diffuse .6 phong 0 } }

#include "colors.inc"
#include "textures.inc"
#include "shapes.inc"
#include "rp.inc" // "rp2.inc" = Bestandteil von rp.inc
#include "metals.inc"

#declare Scale = 10;
#declare Direction = 1; // 1, 2, ...
#declare Camera_Position = < 0.0, 2.0,-2.5*Direction >*Scale;
#declare Camera_lookat =   < 0.0, 0.3, 0.0 >*Scale;

camera { location Camera_Position
         direction z*Direction up y right x*4/3
         look_at  Camera_lookat }
/*        
light_source	{ < 1000, 1000,-500 >*Scale Weiss*.5 }
light_source	{ <  500,  500,-500 >*Scale Weiss*.4 }
light_source	{ <    0,  100,-500 >*Scale Weiss*.3 }
light_source	{ < -500,   50,-500 >*Scale Weiss*.2 }
light_source	{ <-1000,   10,-500 >*Scale Weiss*.1 }
*/

light_source	{ < 0, 5, 0 >*Scale Weiss*.5 }
light_source	{ < 2, 5, 0 >*Scale Weiss*.3 }
light_source	{ <-2, 5, 0 >*Scale Weiss*.3 }

background { color rgb < 160/255, 160/255, 160/255 > }  

plane { y, 0.0 pigment { checker Weiss*.75, Weiss*0.6 scale .5*Scale } finish { reflection 0.2 } rotate y*0 }

fog { fog_type 2 distance 5 color rgb < 160/255, 160/255, 160/255 > fog_offset 0.1 fog_alt 0.2 turbulence 0.8 }

#declare Textur_Bluete = texture { pigment { rgbt < 1, 1, 1, 0.2> } finish  { phong 0 } }

#declare Textur_Vase =
texture {
  pigment { radial frequency 1 
    color_map {
      [ (1/9)*1 color rgb < 4/4, 2/4, 4/4 > ]
      [ (1/9)*2 color rgb < 4/4, 3/4, 3/4 > ]
      [ (1/9)*3 color rgb < 4/4, 4/4, 2/4 > ]
      [ (1/9)*4 color rgb < 4/4, 4/4, 2/4 > ]
      [ (1/9)*5 color rgb < 3/4, 4/4, 3/4 > ]
      [ (1/9)*6 color rgb < 2/4, 4/4, 4/4 > ]
      [ (1/9)*7 color rgb < 2/4, 4/4, 4/4 > ]
      [ (1/9)*8 color rgb < 3/4, 3/4, 4/4 > ]
      [ (1/9)*9 color rgb < 4/4, 2/4, 4/4 > ] }
  } 
  finish  { phong 1 reflection .1 }
}

#declare Textur_Geschirr =
texture {
  pigment { radial frequency 1 
    color_map {
      [ (1/9)*1 color rgb < 4/4, 2/4, 4/4 > ]
      [ (1/9)*2 color rgb < 4/4, 3/4, 3/4 > ]
      [ (1/9)*3 color rgb < 4/4, 4/4, 2/4 > ]
      [ (1/9)*4 color rgb < 4/4, 4/4, 2/4 > ]
      [ (1/9)*5 color rgb < 3/4, 4/4, 3/4 > ]
      [ (1/9)*6 color rgb < 2/4, 4/4, 4/4 > ]
      [ (1/9)*7 color rgb < 2/4, 4/4, 4/4 > ]
      [ (1/9)*8 color rgb < 3/4, 3/4, 4/4 > ]
      [ (1/9)*9 color rgb < 4/4, 2/4, 4/4 > ] }
  } 
  finish  { phong 1 reflection .1 }
}

#declare Holz = texture { Yellow_Pine scale 1.5 rotate y*90 }

#include "sPatch_Tisch.inc"
#include "sPatch_Stuhl.inc"
#include "sPatch_Geschirr.inc"
#include "sPatch_Vase.inc"
/*
#declare sPatch_Geschirr = union {
  object { sPatch_Teller1 } 
  object { sPatch_Teller2    translate < 0.0, 0.14, 0.0 > } 
  union {
    object { sPatch_Teller3 }
    object { sPatch_Teeloeffel }
   translate < 2.0, 0.00, 2.0 > } 
  object { sPatch_Tasse      translate < 2.0, 0.07, 2.0 > }
  object { sPatch_Eierbecher translate < 0.0, 0.00, 2.0 > }
  object { sPatch_Glas       translate <-1.5, 0.00, 2.0 > } 
  object { sPatch_Loeffel scale .20 translate < 2.0, 0.00,-1.0 > }
  object { sPatch_Gabel   scale .20 translate <-2.0, 0.00,-1.0 > }
  object { sPatch_Messer  scale .20 translate < 2.5, 0.00,-1.0 > }
}*/

#declare sPatch_Geschirr = union {
  object { sPatch_Teller2    translate < 0.0, 0.00, 0.0 > } 
  union {
    object { sPatch_Teller3 }
    object { sPatch_Teeloeffel }
   translate < 2.0, 0.00, 2.0 > } 
  object { sPatch_Tasse      translate < 2.0, 0.07, 2.0 > }
  object { sPatch_Eierbecher translate < 0.0, 0.00, 2.0 > }
  object { sPatch_Glas       translate <-1.5, 0.00, 2.0 > }
  object { sPatch_Gabel   scale .20 translate <-1.5, 0.00,-1.0 > }
  object { sPatch_Messer  scale .20 translate < 1.5, 0.00,-1.0 > }
}

union {

  object { sPatch_Tisch    scale Scale }
  object { sPatch_Stuhl    scale Scale rotate y*0   translate < 0.50, 0.00, 0.75 >*Scale } 
  object { sPatch_Stuhl    scale Scale rotate y*0   translate <-0.50, 0.00, 0.75 >*Scale } 
  object { sPatch_Stuhl    scale Scale rotate y*180 translate < 0.50, 0.00,-0.75 >*Scale } 
  object { sPatch_Stuhl    scale Scale rotate y*135 translate <-0.30, 0.00,-1.10 >*Scale } 

  object { sPatch_Geschirr                          translate < 0.50, 0.86,-0.50 >*Scale } 
  object { sPatch_Geschirr                          translate <-0.50, 0.86,-0.50 >*Scale } 
  object { sPatch_Geschirr             rotate y*180 translate < 0.50, 0.86, 0.50 >*Scale } 
  object { sPatch_Geschirr             rotate y*180 translate <-0.50, 0.86, 0.50 >*Scale }

  object { sPatch_Vase     scale .35                translate < 0.00, 0.86, 0.00 >*Scale }

  object { sPatch_Karaffe  scale 1.25  rotate y*90  translate <-0.25, 0.86, 0.00 >*Scale }
  object { sPatch_Kanne    scale 1.35  rotate y*90  translate < 0.25, 0.86, 0.00 >*Scale }
  
rotate y*-40 }
